==> paraview-5.12.1-4-x86_64.pkg.tar.zst: opt/paraview/lib/python3.12/site-packages/paraview/modules/__init__.py <==
r"""
This is the package for paraview's extension modules.
"""

#------------------------------------------------------------------------------
# list the contents
__all__ = [
    'vtkIOVisItBridge',
    'vtkRemotingClientServerStream',
    'vtkPVVersioning',
    'vtkPVVTKExtensionsCore',
    'vtkRemotingCore',
    'vtkRemotingServerManager',
    'vtkRemotingViews',
    'vtkRemotingViewsPython',
    'vtkRemotingServerManagerPython',
    'vtkPVVTKExtensionsPoints',
    'vtkPVVTKExtensionsIOCore',
    'vtkPVVTKExtensionsIOSPCTH',
    'vtkPVVTKExtensionsIOCGNSWriter',
    'vtkPVVTKExtensionsIOParallelCGNSWriter',
    'vtkPVVTKExtensionsIOImage',
    'vtkPVVTKExtensionsIOExodus',
    'vtkPVVTKExtensionsIOEnSight',
    'vtkPVVTKExtensionsIOAMR',
    'vtkPVVTKExtensionsFiltersStatistics',
    'vtkPVVTKExtensionsFiltersPython',
    'vtkPVVTKExtensionsFiltersGeneral',
    'vtkPVVTKExtensionsFiltersParallelDIY2',
    'vtkPVVTKExtensionsFiltersMaterialInterface',
    'vtkPVVTKExtensionsFiltersGeneralMPI',
    'vtkPVVTKExtensionsExtractionPython',
    'vtkRemotingExport',
    'vtkPVVTKExtensionsExtraction',
    'vtkRemotingLive',
    'vtkRemotingMisc',
    'vtkPVVTKExtensionsIOGeneral',
    'vtkPVVTKExtensionsAMR',
    'vtkRemotingApplication',
    'vtkRemotingSettings',
    'vtkRemotingAnimation',
    'vtkPVVTKExtensionsInteractionStyle',
    'vtkPVVTKExtensionsFiltersRendering',
    'vtkPVVTKExtensionsMisc',
    'vtkPVCatalyst',
    'vtkPVAdaptorsPagosa',
    'vtkPVPythonCatalyst',
    'vtkPVClientWeb',
    'vtkPVInSitu',
]

==> paraview-5.13.3-5-x86_64.pkg.tar.zst: opt/paraview/lib/python3.13/site-packages/paraview/modules/__init__.py <==
r"""
This is the package for paraview's extension modules.
"""

#------------------------------------------------------------------------------
# list the contents
__all__ = [
    'vtkIOVisItBridge',
    'vtkRemotingClientServerStream',
    'vtkPVVersioning',
    'vtkPVVTKExtensionsCore',
    'vtkRemotingCore',
    'vtkRemotingServerManager',
    'vtkRemotingViews',
    'vtkRemotingViewsPython',
    'vtkRemotingServerManagerPython',
    'vtkPVVTKExtensionsPoints',
    'vtkPVVTKExtensionsIOCore',
    'vtkPVVTKExtensionsIOSPCTH',
    'vtkPVVTKExtensionsIOCGNSWriter',
    'vtkPVVTKExtensionsIOParallelCGNSWriter',
    'vtkPVVTKExtensionsIOImage',
    'vtkPVVTKExtensionsIOExodus',
    'vtkPVVTKExtensionsIOEnSight',
    'vtkPVVTKExtensionsIOAMR',
    'vtkPVVTKExtensionsFiltersStatistics',
    'vtkPVVTKExtensionsFiltersPython',
    'vtkPVVTKExtensionsFiltersGeneral',
    'vtkPVVTKExtensionsFiltersParallelDIY2',
    'vtkPVVTKExtensionsFiltersParallel',
    'vtkPVVTKExtensionsFiltersMaterialInterface',
    'vtkPVVTKExtensionsFiltersGeneralMPI',
    'vtkPVVTKExtensionsFiltersFlowPaths',
    'vtkPVVTKExtensionsExtractionPython',
    'vtkRemotingImport',
    'vtkPVVTKExtensionsIOImport',
    'vtkRemotingExport',
    'vtkPVVTKExtensionsExtraction',
    'vtkRemotingLive',
    'vtkRemotingMisc',
    'vtkPVVTKExtensionsIOGeneral',
    'vtkPVVTKExtensionsAMR',
    'vtkRemotingApplication',
    'vtkRemotingSettings',
    'vtkRemotingAnimation',
    'vtkPVVTKExtensionsInteractionStyle',
    'vtkPVVTKExtensionsFiltersRendering',
    'vtkPVVTKExtensionsMisc',
    'vtkPVCatalyst',
    'vtkPVPythonCatalyst',
    'vtkPVClientWeb',
    'vtkPVInSitu',
]
